@@ -1,6 +1,6 @@
 /*
  * This file is part of Xpra.
- * Copyright (C) 2010-2017 Antoine Martin <antoine@devloop.org.uk>
+ * Copyright (C) 2010-2017 Antoine Martin <antoine@xpra.org>
  * Licensed under MPL 2.0, see:
  * http://www.mozilla.org/MPL/2.0/
  *
@@ -226,8 +226,8 @@ KEYSYM_TO_UNICODE = {
 	"Otilde" : 0x00D5,
 	"Odiaeresis" : 0x00D6,
 	"multiply" : 0x00D7,
-	"Oslash" : 0x00D8,
 	"Ooblique" : 0x00D8,
+	"Oslash" : 0x00D8,
 	"Ugrave" : 0x00D9,
 	"Uacute" : 0x00DA,
 	"Ucircumflex" : 0x00DB,
@@ -1621,6 +1621,7 @@ KEYSYM_TO_UNICODE = {
 };
 
 CHAR_TO_NAME = {
+	" "					: "space",
 	};
 //console.debug("KEYSYM_TO_UNICODE=", KEYSYM_TO_UNICODE);
 for (var keysym in KEYSYM_TO_UNICODE) {
@@ -1736,6 +1737,11 @@ for (i=0; i<10; i++) {
 for (i=1; i<=24; i++) {
 	CHARCODE_TO_NAME[111+i] = "F"+i;
 }
+//overrides: only for 'de' layout?
+CHARCODE_TO_NAME[192] = "dead_circumflex"
+CHARCODE_TO_NAME[219] = "backtick"
+CHARCODE_TO_NAME[221] = "dead_acute"
+CHARCODE_TO_NAME[220] = "dead_circumflex"
 
 
 /**
@@ -1755,7 +1761,13 @@ function get_event_modifiers(event) {
 			modifiers.push("meta");
 		if (event.getModifierState("Shift"))
 			modifiers.push("shift");
-		//event.getModifierState("ScrollLock") || event.getModifierState("Scroll")
+		if (event.getModifierState("CapsLock"))
+			modifiers.push("capslock");
+		if (event.getModifierState("NumLock"))
+			modifiers.push("numlock");
+		//ScrollLock
+		//Fn
+		//AltGraph
 	}
 	else if (event.modifiers) {
 		if (event.modifiers & Event.ALT_MASK)
